@@ -16,6 +16,8 @@ import aws_cdk.aws_cloudwatch_actions._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_events_targets._jsii
 import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_lambda_event_sources._jsii
+import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_route53_targets._jsii
 import aws_cdk.aws_s3._jsii
@@ -27,7 +29,7 @@ import cdk_watchful._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "construct-hub", "0.1.24", __name__[0:-6], "construct-hub@0.1.24.jsii.tgz"
+    "construct-hub", "0.1.27", __name__[0:-6], "construct-hub@0.1.27.jsii.tgz"
 )
 
 __all__ = [
